TOPSIS
Submitted By: Manjot Singh Kandhari - 102017129.

Type: Package.

Title: TOPSIS method for multiple-criteria decision making (MCDM).

Version: 1.0.0.

Date: 22/01/23.

Author: Manjot Singh Kandhari.

Maintainer: Manjot Singh Kandhari smanjot444@gmail.com.

Description: Evaluation of alternatives based on multiple criteria using TOPSIS method.